function loadScript(url) {
    const script = document.createElement('script');
    script.src = url;
    document.head.appendChild(script);
}

function highlightQueryWords(text, queryWords) {
    // Sanitize html tags from text and queryWords
    text = text.replace(/</g, '&lt;').replace(/>/g, '&gt;');
    queryWords = queryWords.map(word => word.replace(/</g, '&lt;').replace(/>/g, '&gt;'));

    queryWords
        .filter(word => word.length >= 3)
        .forEach(word => {
            const regex = new RegExp(`(?:\\b|(?<=\\W))(${word})(?:\\b|(?<=\\W))`, 'gi');
            text = text.replace(regex, '<span class="highlighted">$1</span>');
        });
    return text;
}

const urlParams = new URLSearchParams(window.location.search);
const query = urlParams.get('q');
const queryWords = query.split(" ");

var urlParts = window.location.pathname.split("/").filter(function (el) {
    return el !== "";
});

var neteye_version = urlParts[0];

const url='https://search.neteye.guide/query?neteye_version=' + encodeURIComponent(neteye_version) + '&query=' + encodeURIComponent(query);

// Get current user guide base URL
const UG_base_url = window.location.origin;

// execute request only if current neteye version is within the last 10 versions.
const versions = JSON.parse(Cookies.get('neteye_userguide_versions'));
const last10Versions = versions.slice(0, 10).map(version => version.version);
if (last10Versions.includes(neteye_version)) {
    fetch(url)
        .then(response => response.json())
        .then(result => {
            if (result.length) {
                result.forEach((result) => {
                    let result_item = document.createElement("li");
                    const result_link = document.createElement("a");
                    result_link.href = UG_base_url + result.href;
                    result_link.textContent = result.caption;
                    const result_context = document.createElement("p");
                    result_context.className = "context";
                    result_context.innerHTML = highlightQueryWords(result.context, queryWords);
                    result_item.appendChild(result_link);
                    result_item.appendChild(result_context);

                    document.querySelector("#search-results").appendChild(result_item);
                });

                // Track search event for new search
                window._paq.push(['trackSiteSearch', query, false, result.length]);

            } else {
                loadScript('searchindex.js');
            }

            setCookie('neteye_userguide_search_performed', 'true'); // Set cookie when search is performed
        })
        .catch(() => {
            // Called in case of an error in the call to our search functionality,
            // the fallback is then on sphinx search
            loadScript('searchindex.js');
        });
} else {
    loadScript('searchindex.js');
}


$(document).ready(function(){
    document.querySelector('#search-banner .banner-title .query').textContent += query;
    let numberOfResults = 0;
    const searchSummary = document.querySelector('.search-summary');
    if(!searchSummary.textContent.includes('Your search did not match any documents')) {
        const bannerTitle = document.querySelector('#search-banner .banner-title');
        bannerTitle.insertBefore(searchSummary, bannerTitle.firstChild);
        numberOfResults = document.querySelectorAll("#search-results ul.search li").length;
    } else {
        searchSummary.textContent = 'No results found.';
    }
    if (numberOfResults !== 0) {
        // Track search event for legacy search
        window._paq.push(['trackSiteSearch', query, false, numberOfResults]);
    }
});
