/* Init current version */
var urlParts = window.location.pathname.split("/").filter(function (el) {
  return el !== "";
});
if (urlParts.length > 0 && !isNaN(parseFloat(urlParts[0]))) {
  document.querySelector(
    "#change-version #dropdownMenuVersion .current-version",
  ).innerHTML = urlParts[0];
}

/* Load all versions */
fetch("/versions.json", { cache: "no-cache" })
  .then((response) => response.json())
  .then((data) => initVersions(data))
  .catch(() => initVersions([]));

document
  .querySelector("#topbar .hamburger-icon")
  .addEventListener("click", function () {
    document.body.classList.toggle("menu-open");
  });

function setNeteyeVersionsInCookie(name, value, days) {
  var expires = "";
  if (days) {
    var date = new Date();
    date.setTime(date.getTime() + days * 24 * 60 * 60 * 1000);
    expires = "; expires=" + date.toUTCString();
  }
  document.cookie = name + "=" + (value || "") + expires + "; path=/";
}

function redirectToArchivedPage() {
  window.location = "next/archived.html";
}

function change_version(version) {
  if (window.location.pathname.includes("/archived.html")) {
    window.location = "/" + version + "/index.html";
    return;
  }

  const current_location = window.location.pathname.replace(/^\/.*?\//, "/");
  window.location = "/" + version + current_location + window.location.hash;
}

async function initVersions(versions) {
  // get last archived version from /last_archived_version.json
  const last_archived_version = (
    await (await fetch("/last_archived_version.json")).json()
  ).last_archived_version;

  //version will be 4.xx, drop the 4. and convert to int
  const last_archived_minor = parseInt(last_archived_version.split(".")[1]);

  // drop versions which are less or equal to the last archived version
  versions = versions.filter((version) => {
    const minor = parseInt(version.version.split(".")[1]);
    return minor > last_archived_minor;
  });

  const sortedVersions = sortVersions(versions);
  setNeteyeVersionsInCookie(
    "neteye_userguide_versions",
    JSON.stringify(sortedVersions),
    365,
  );
  for (let versionObj of sortedVersions) {
    let releaseStatus = "";
    if ("release_status" in versionObj) {
      releaseStatus = versionObj["release_status"];
    }
    const a = document.createElement("a");
    a.className = "dropdown-item";
    a.onclick = () => change_version(versionObj["version"]);
    a.innerHTML = `<span class="desktop-version-label">Version </span><span class="mobile-version-label">v</span>${versionObj["version"]}${releaseStatus}`;
    document.querySelector("#change-version .dropdown-menu").appendChild(a);
  }

  const a = document.createElement("a");
  a.className = "dropdown-item";
  a.onclick = () => redirectToArchivedPage();
  a.innerHTML = `<span class="desktop-version-label">Older Versions</span><span class="mobile-version-label">Old Versions</span>`;

  document.querySelector("#change-version .dropdown-menu").appendChild(a);
}

function sortVersions(versions) {
  versions.sort((a, b) =>
    (parseInt(b.version.split(".")[0]) === parseInt(a.version.split(".")[0]) &&
      parseInt(b.version.split(".")[1]) >= parseInt(a.version.split(".")[1])) ||
    parseInt(b.version.split(".")[0]) > parseInt(a.version.split(".")[0])
      ? 1
      : -1,
  );

  return tagCurrentAndNextVersionReleaseStatus(versions);
}

function tagCurrentAndNextVersionReleaseStatus(versions) {
  for (let i = 0; i < versions.length; ++i) {
    if (versions[i]["released"]) {
      versions[i]["release_status"] = " (current)";
      const next = i - 1;
      if (next >= 0) {
        versions[next]["release_status"] = " (next)";
        const alpha = next - 1;
        if (alpha >= 0) {
          versions[alpha]["release_status"] = " (alpha)";
        }
      }
      break;
    }
  }

  return versions;
}
